@@ -173,7 +173,7 @@ class ApiKeyTranslate:
 
         .. 谷歌API调用限制
             最大并发量: 128
-            最大请求体大小: 102400 Byte
+            最大请求体大小: 102400 bytes
 
         基本用法:
             >>> from pygtrans import ApiKeyTranslate
