@@ -12,4 +12,4 @@ class TranslateResponse:
         self.model = model
 
     def __repr__(self):
-        return self.__class__.__qualname__ + f'(translatedText={self.translatedText}, detectedSourceLanguage={self.detectedSourceLanguage}, model={self.model})'
+        return self.__class__.__qualname__ + f'(translatedText={repr(self.translatedText)}, detectedSourceLanguage={repr(self.detectedSourceLanguage)}, model={repr(self.model)})'
